use super::component::LoggerComponent;
use std::io::Error;

pub struct ConsoleComponent {}

impl ConsoleComponent {
    pub fn new() -> Self {
        ConsoleComponent {}
    }
}

impl LoggerComponent for ConsoleComponent {
    fn log(&mut self, msg: &str) -> Result<(), Error> {
        println!("{}", msg);
        Ok(())
    }
}
